const fs = {};
function netlifyExtension() {
  return [
    {
      name: "vite-plugin-netlify-extension",
      config(config) {
        return {
          ...config,
          base: "",
          build: {
            ...config.build,
            outDir: "../../.ntli/site/static/ui"
          },
          root: "./src/ui"
        };
      }
    },
    {
      name: "vite-plugin-netlify-extension-dev",
      apply(_, { mode, command }) {
        return mode === "development" && command === "serve";
      },
      configureServer(server) {
        const detailsFilePath = fs.resolve(
          server.config.configFile ?? "",
          "../details.md"
        );
        server.watcher.add(detailsFilePath);
        const extensionYamlPath = fs.resolve(
          server.config.configFile ?? "",
          "../extension.yaml"
        );
        server.watcher.add(extensionYamlPath);
        const extensionYmlPath = fs.resolve(
          server.config.configFile ?? "",
          "../extension.yaml"
        );
        server.watcher.add(extensionYmlPath);
        server.middlewares.use((req, res, next) => {
          if (req.url === "/_netlify_extension_vite_plugin.json") {
            res.setHeader("Content-Type", "application/json");
            res.setHeader("access-control-allow-origin", "*");
            return res.end(JSON.stringify(server.config.server.hmr));
          }
          if (req.url === "/manifest.json") {
            const manifestFile = fs.readFileSync(
              "./.ntli/site/static/manifest.json",
              "utf-8"
            );
            res.setHeader("Content-Type", "application/json");
            res.setHeader("access-control-allow-origin", "*");
            return res.end(manifestFile);
          }
          if (req.url === "/details.md") {
            if (!server.config.configFile) {
              next();
              return;
            }
            const detailsFilePath2 = fs.resolve(
              server.config.configFile,
              // path of the vite.config.ts file
              "../details.md"
            );
            const detailsFile = fs.readFileSync(detailsFilePath2, "utf-8");
            res.setHeader("Content-Type", "text/markdown");
            res.setHeader("access-control-allow-origin", "*");
            return res.end(detailsFile);
          }
          next();
          return;
        });
      },
      config(config) {
        var _a;
        if (((_a = config.server) == null ? void 0 : _a.hmr) === false) {
          return config;
        }
        const updatedConfig = {
          ...config,
          server: {
            ...config.server
          }
        };
        if (process.env["DEPLOY_URL"] && (!updatedConfig.server.hmr || typeof updatedConfig.server.hmr === "object")) {
          const deployUrl = new URL(process.env["DEPLOY_URL"]);
          updatedConfig.server.hmr = {
            ...updatedConfig.server.hmr ?? {},
            /**
             * The host and port of the HMR server need to be set to allow connections from different origins.
             * This is necessary for Netlify UI to connect and listen to the dev server.
             */
            host: "0.0.0.0",
            port: parseInt(deployUrl.port) + 2
          };
        }
        return updatedConfig;
      },
      handleHotUpdate(options) {
        if (options.file.endsWith("details.md")) {
          options.server.ws.send("EXTENSION_DEV_EVENT::UPDATE:DETAILS");
          return;
        }
        if (options.file.endsWith("extension.yaml") || options.file.endsWith("extension.yml")) {
          options.server.ws.send("EXTENSION_DEV_EVENT::UPDATE:EXTENSIONYAML");
          return;
        }
        options.server.ws.send("EXTENSION_DEV_EVENT::UPDATE");
      }
    }
  ];
}
export {
  netlifyExtension
};
//# sourceMappingURL=vite_plugin_netlify_extension.js.map
